# -*-coding:utf-8 -*- #
# --------------------------------------------------------------------------
# ProjectName: protest
# FileName: read_excel.py
# Author: xiao tian
# Datetime: 2025/5/10 10:53
# Description:
# 测试
# 命名规范：文件名全小写+下划线，类名大驼峰，方法和变量小写+下划线连接，
# 常量大写，变量和常量用名词，方法用动词
# --------------------------------------------------------------------------


import openpyxl
from APIAutoTest_v3test import log_decorator
from APIAutoTest_v3test.common.read_json import read_json
from APIAutoTest_v3test.common.read_system_ini import ReadSystemIni
from APIAutoTest_v3test.common.read_user_ini import ReadUserIni
from APIAutoTest_v3test.data_config.settings import *


class ReadExcel:
    @log_decorator
    def __init__(self,username):
        """获取excel的路径及工作表的名称，加载工作簿获取工作表；获取所以json文件的路径，获取json文件内容的python对象"""
        self.userini = ReadUserIni(username)
        self.sysini = ReadSystemIni()

        self.case_data_dict = read_json(self.userini.get_file_path(FILE_CASE))
        self.expect_data_dict = read_json(self.userini.get_file_path(FILE_EXPECT))
        self.sql_data_dict = read_json(self.userini.get_file_path(FILE_SQL))

        wb = openpyxl.load_workbook(self.userini.get_file_path(FILE_EXCEL))
        self.ws = wb[self.userini.get_table_name(TABLE_NAME_KEY)]


    @log_decorator
    def get_call_value(self,column,row):
        cell_value = self.ws[column+str(row)].value
        if isinstance(cell_value,str) and len(cell_value.strip())> 0 :
            return cell_value.strip()

    @log_decorator
    def module_name(self,row):
        return self.get_call_value(MODULE,row)

    @log_decorator
    def api_name(self,row):
        return self.get_call_value(API,row)

    @log_decorator
    def case_req(self,row):
        return self.get_call_value(METHOD,row)

    @log_decorator
    def case_url(self,row):
        value = self.get_call_value(PATH,row)
        if value:
            return self.sysini.get_host(HOST_KEY) + value

    @log_decorator
    def case_mime(self,row):
        value = self.get_call_value(MIME,row)
        if value:
            return value.lower()

    @log_decorator
    def case_data(self,row):
        case_data_key = self.get_call_value(CASE,row)
        module_name = self.module_name(row)
        api_name = self.api_name(row)
        if case_data_key and module_name and api_name:
           return self.case_data_dict[module_name][api_name][case_data_key]

    @log_decorator
    def expect_data(self, row):
        expect_data_key = self.get_call_value(EXPECT,row)
        module_name = self.module_name(row)
        api_name = self.api_name(row)
        if expect_data_key and module_name and api_name:
            return self.expect_data_dict[module_name][api_name][expect_data_key]

    @log_decorator
    def sql_data(self, row):
        sql_data_key = self.get_call_value(SQL,row)
        module_name = self.module_name(row)
        api_name = self.api_name(row)
        if sql_data_key and module_name and api_name:
            return self.sql_data_dict[module_name][api_name][sql_data_key]

    @log_decorator
    def sql_type(self,row):
        value = self.get_call_value(SQLTYPE,row)
        if value:
            return value.lower()

    @log_decorator
    def update_key(self,row):
        return self.get_call_value(UPDATEKEY,row)

    @log_decorator
    def get_data(self):
        list_data = []
        for  row in range(2,self.ws.max_row+1):
            req = self.case_req(row)
            url = self.case_url(row)
            mime = self.case_mime(row)
            case = self.case_data(row)
            expect = self.expect_data(row)
            sql_data = self.sql_data(row)
            sql_type = self.sql_type(row)
            update_key = self.update_key(row)
            if req and url and expect:
                list_data.append([req, url, mime, case, expect, sql_type, sql_data, update_key])
        else:
            return list_data





if __name__ == '__main__':
    excel = ReadExcel("bpm")
    print(excel.get_data())

